==> haskell-uri-encode-1.5.0.7-260-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-encode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-encode
version:              1.5.0.7
visibility:           public
id:                   uri-encode-1.5.0.7-4bECUAaW7qm6a3JoyHcF2c
key:                  uri-encode-1.5.0.7-4bECUAaW7qm6a3JoyHcF2c
license:              BSD-3-Clause
maintainer:           code@silk.co
author:               Silk
synopsis:             Unicode aware uri-encoding
description:
    This package allows you to uri encode and uri decode
    Strings, Texts and ByteString values.

category:             Network, Web
abi:                  abb82a819dbfd4443b0cf4613d30cc49
exposed:              True
exposed-modules:      Network.URI.Encode
import-dirs:          /usr/lib/ghc-9.4.8/site-local/uri-encode-1.5.0.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/uri-encode-1.5.0.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/uri-encode-1.5.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-encode
hs-libraries:         HSuri-encode-1.5.0.7-4bECUAaW7qm6a3JoyHcF2c
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-uri-2.6.4.2-G7m9o4Qp8JT5z4xQAeqaNT text-2.0.2
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:   /usr/share/doc/haskell-uri-encode/html/uri-encode.haddock
haddock-html:         /usr/share/doc/haskell-uri-encode/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uri-encode-1.5.0.7-261-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-encode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-encode
version:              1.5.0.7
visibility:           public
id:                   uri-encode-1.5.0.7-5WzIB0YcO0zG2nDVZ5NQaE
key:                  uri-encode-1.5.0.7-5WzIB0YcO0zG2nDVZ5NQaE
license:              BSD-3-Clause
maintainer:           code@silk.co
author:               Silk
synopsis:             Unicode aware uri-encoding
description:
    This package allows you to uri encode and uri decode
    Strings, Texts and ByteString values.

category:             Network, Web
abi:                  8ce4c15e59a868adfccc15106a7d0d61
exposed:              True
exposed-modules:      Network.URI.Encode
import-dirs:          /usr/lib/ghc-9.4.8/site-local/uri-encode-1.5.0.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/uri-encode-1.5.0.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/uri-encode-1.5.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-encode
hs-libraries:         HSuri-encode-1.5.0.7-5WzIB0YcO0zG2nDVZ5NQaE
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    network-uri-2.6.4.2-L8nDuI5zE9yEZ3pwnnu7AU text-2.0.2
    utf8-string-1.0.2-4puy9i6JhHg6bynwSjfiUA

haddock-interfaces:   /usr/share/doc/haskell-uri-encode/html/uri-encode.haddock
haddock-html:         /usr/share/doc/haskell-uri-encode/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
